@@ -12,7 +12,7 @@ use warnings;
 
 package Dist::Zilla::Plugin::Git::Push;
 {
-  $Dist::Zilla::Plugin::Git::Push::VERSION = '2.006';
+  $Dist::Zilla::Plugin::Git::Push::VERSION = '2.007';
 }
 # ABSTRACT: push current branch
 
@@ -20,6 +20,9 @@ use Moose;
 use MooseX::Has::Sugar;
 use MooseX::Types::Moose qw{ ArrayRef Str };
 
+use namespace::autoclean;
+
+with 'Dist::Zilla::Role::BeforeRelease';
 with 'Dist::Zilla::Role::AfterRelease';
 with 'Dist::Zilla::Role::Git::Repo';
 
@@ -27,6 +30,8 @@ sub mvp_multivalue_args { qw(push_to) }
 
 # -- attributes
 
+has remotes_must_exist => ( ro, isa=>'Bool', default=>1 );
+
 has push_to => (
   is   => 'ro',
   isa  => 'ArrayRef[Str]',
@@ -35,6 +40,31 @@ has push_to => (
 );
 
 
+sub before_release {
+    my $self = shift;
+
+    return unless $self->remotes_must_exist;
+
+    my %valid_remote = map { $_ => 1 } $self->git->remote;
+    my @bad_remotes;
+
+    # Make sure the remotes we'll be pushing to exist
+    for my $remote ( @{ $self->push_to } ) {
+      $remote =~ s/\s.*//s;     # Discard branch (if specified)
+      if ($remote =~ m![:/]!) {
+        # Appears to be a URL or path, don't check it
+        $self->log("Will push to $remote (not checked)");
+      } else {
+        # Named remotes must exist
+        push @bad_remotes, $remote unless $valid_remote{$remote};
+      }
+    }
+
+    $self->log_fatal("These remotes do not exist: @bad_remotes")
+        if @bad_remotes;
+}
+
+
 sub after_release {
     my $self = shift;
     my $git  = $self->git;
@@ -60,15 +90,16 @@ Dist::Zilla::Plugin::Git::Push - push current branch
 
 =head1 VERSION
 
-version 2.006
+version 2.007
 
 =head1 SYNOPSIS
 
 In your F<dist.ini>:
 
     [Git::Push]
-    push_to = origin      ; this is the default
+    push_to = origin       ; this is the default
     push_to = origin HEAD:refs/heads/released ; also push to released branch
+    remotes_must_exist = 1 ; this is the default
 
 =head1 DESCRIPTION
 
@@ -84,9 +115,18 @@ The plugin accepts the following options:
 push_to - the name of the a remote to push to. The default is F<origin>.
 This may be specified multiple times to push to multiple repositories.
 
+=item *
+
+remotes_must_exist - if true, then Git::Push checks before a release
+to ensure that all named remotes specified in C<push_to> are
+configured in your repo.  The default is true.  Remotes specified as a
+URL or path are not checked, but will produce a
+C<Will push to %s (not checked)> message.
+
 =back
 
 =for Pod::Coverage after_release
+    before_release
     mvp_multivalue_args
 
 =head1 AUTHOR
