@@ -8,13 +8,12 @@
 #
 package Dist::Zilla::Role::Git::Repo;
 {
-  $Dist::Zilla::Role::Git::Repo::VERSION = '2.006';
+  $Dist::Zilla::Role::Git::Repo::VERSION = '2.007';
 }
 
 # ABSTRACT: Provide repository information for Git plugins
 
 use Moose::Role;
-use Git::Wrapper ();
 
 has 'repo_root'   => ( is => 'ro', isa => 'Str', default => '.' );
 
@@ -24,7 +23,10 @@ my %cached_wrapper;
 sub git {
   my $root = shift->repo_root;
 
-  $cached_wrapper{$root} ||= Git::Wrapper->new( $root );
+  $cached_wrapper{$root} ||= do {
+    require Git::Wrapper;
+    Git::Wrapper->new( $root );
+  };
 }
 
 1;
@@ -39,7 +41,7 @@ Dist::Zilla::Role::Git::Repo - Provide repository information for Git plugins
 
 =head1 VERSION
 
-version 2.006
+version 2.007
 
 =head1 DESCRIPTION
 
